# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class OrmOnPremiseVolumeConfigGoogleDisk(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'fs_type': 'str',
        'pv_name': 'str',
        'pvc_name': 'str',
        'volume_handle': 'str',
        'volume_size_in_gb': 'float'
    }

    attribute_map = {
        'fs_type': 'fs_type',
        'pv_name': 'pv_name',
        'pvc_name': 'pvc_name',
        'volume_handle': 'volume_handle',
        'volume_size_in_gb': 'volume_size_in_gb'
    }

    def __init__(self, fs_type=None, pv_name=None, pvc_name=None, volume_handle=None, volume_size_in_gb=None, local_vars_configuration=None):  # noqa: E501
        """OrmOnPremiseVolumeConfigGoogleDisk - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._fs_type = None
        self._pv_name = None
        self._pvc_name = None
        self._volume_handle = None
        self._volume_size_in_gb = None
        self.discriminator = None

        self.fs_type = fs_type
        if pv_name is not None:
            self.pv_name = pv_name
        if pvc_name is not None:
            self.pvc_name = pvc_name
        self.volume_handle = volume_handle
        self.volume_size_in_gb = volume_size_in_gb

    @property
    def fs_type(self):
        """Gets the fs_type of this OrmOnPremiseVolumeConfigGoogleDisk.  # noqa: E501


        :return: The fs_type of this OrmOnPremiseVolumeConfigGoogleDisk.  # noqa: E501
        :rtype: str
        """
        return self._fs_type

    @fs_type.setter
    def fs_type(self, fs_type):
        """Sets the fs_type of this OrmOnPremiseVolumeConfigGoogleDisk.


        :param fs_type: The fs_type of this OrmOnPremiseVolumeConfigGoogleDisk.  # noqa: E501
        :type fs_type: str
        """
        if self.local_vars_configuration.client_side_validation and fs_type is None:  # noqa: E501
            raise ValueError("Invalid value for `fs_type`, must not be `None`")  # noqa: E501

        self._fs_type = fs_type

    @property
    def pv_name(self):
        """Gets the pv_name of this OrmOnPremiseVolumeConfigGoogleDisk.  # noqa: E501


        :return: The pv_name of this OrmOnPremiseVolumeConfigGoogleDisk.  # noqa: E501
        :rtype: str
        """
        return self._pv_name

    @pv_name.setter
    def pv_name(self, pv_name):
        """Sets the pv_name of this OrmOnPremiseVolumeConfigGoogleDisk.


        :param pv_name: The pv_name of this OrmOnPremiseVolumeConfigGoogleDisk.  # noqa: E501
        :type pv_name: str
        """

        self._pv_name = pv_name

    @property
    def pvc_name(self):
        """Gets the pvc_name of this OrmOnPremiseVolumeConfigGoogleDisk.  # noqa: E501


        :return: The pvc_name of this OrmOnPremiseVolumeConfigGoogleDisk.  # noqa: E501
        :rtype: str
        """
        return self._pvc_name

    @pvc_name.setter
    def pvc_name(self, pvc_name):
        """Sets the pvc_name of this OrmOnPremiseVolumeConfigGoogleDisk.


        :param pvc_name: The pvc_name of this OrmOnPremiseVolumeConfigGoogleDisk.  # noqa: E501
        :type pvc_name: str
        """

        self._pvc_name = pvc_name

    @property
    def volume_handle(self):
        """Gets the volume_handle of this OrmOnPremiseVolumeConfigGoogleDisk.  # noqa: E501


        :return: The volume_handle of this OrmOnPremiseVolumeConfigGoogleDisk.  # noqa: E501
        :rtype: str
        """
        return self._volume_handle

    @volume_handle.setter
    def volume_handle(self, volume_handle):
        """Sets the volume_handle of this OrmOnPremiseVolumeConfigGoogleDisk.


        :param volume_handle: The volume_handle of this OrmOnPremiseVolumeConfigGoogleDisk.  # noqa: E501
        :type volume_handle: str
        """
        if self.local_vars_configuration.client_side_validation and volume_handle is None:  # noqa: E501
            raise ValueError("Invalid value for `volume_handle`, must not be `None`")  # noqa: E501

        self._volume_handle = volume_handle

    @property
    def volume_size_in_gb(self):
        """Gets the volume_size_in_gb of this OrmOnPremiseVolumeConfigGoogleDisk.  # noqa: E501


        :return: The volume_size_in_gb of this OrmOnPremiseVolumeConfigGoogleDisk.  # noqa: E501
        :rtype: float
        """
        return self._volume_size_in_gb

    @volume_size_in_gb.setter
    def volume_size_in_gb(self, volume_size_in_gb):
        """Sets the volume_size_in_gb of this OrmOnPremiseVolumeConfigGoogleDisk.


        :param volume_size_in_gb: The volume_size_in_gb of this OrmOnPremiseVolumeConfigGoogleDisk.  # noqa: E501
        :type volume_size_in_gb: float
        """
        if self.local_vars_configuration.client_side_validation and volume_size_in_gb is None:  # noqa: E501
            raise ValueError("Invalid value for `volume_size_in_gb`, must not be `None`")  # noqa: E501

        self._volume_size_in_gb = volume_size_in_gb

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrmOnPremiseVolumeConfigGoogleDisk):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrmOnPremiseVolumeConfigGoogleDisk):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class ResponseOrganizationKernelClusterInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'allowed_nodes': 'list[ResponseSimpleKernelClusterNode]',
        'created_dt': 'datetime',
        'id': 'int',
        'kubernetes_namespace': 'str',
        'organization_name': 'str'
    }

    attribute_map = {
        'allowed_nodes': 'allowed_nodes',
        'created_dt': 'created_dt',
        'id': 'id',
        'kubernetes_namespace': 'kubernetes_namespace',
        'organization_name': 'organization_name'
    }

    def __init__(self, allowed_nodes=None, created_dt=None, id=None, kubernetes_namespace=None, organization_name=None, local_vars_configuration=None):  # noqa: E501
        """ResponseOrganizationKernelClusterInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._allowed_nodes = None
        self._created_dt = None
        self._id = None
        self._kubernetes_namespace = None
        self._organization_name = None
        self.discriminator = None

        self.allowed_nodes = allowed_nodes
        self.created_dt = created_dt
        self.id = id
        self.kubernetes_namespace = kubernetes_namespace
        self.organization_name = organization_name

    @property
    def allowed_nodes(self):
        """Gets the allowed_nodes of this ResponseOrganizationKernelClusterInfo.  # noqa: E501


        :return: The allowed_nodes of this ResponseOrganizationKernelClusterInfo.  # noqa: E501
        :rtype: list[ResponseSimpleKernelClusterNode]
        """
        return self._allowed_nodes

    @allowed_nodes.setter
    def allowed_nodes(self, allowed_nodes):
        """Sets the allowed_nodes of this ResponseOrganizationKernelClusterInfo.


        :param allowed_nodes: The allowed_nodes of this ResponseOrganizationKernelClusterInfo.  # noqa: E501
        :type allowed_nodes: list[ResponseSimpleKernelClusterNode]
        """
        if self.local_vars_configuration.client_side_validation and allowed_nodes is None:  # noqa: E501
            raise ValueError("Invalid value for `allowed_nodes`, must not be `None`")  # noqa: E501

        self._allowed_nodes = allowed_nodes

    @property
    def created_dt(self):
        """Gets the created_dt of this ResponseOrganizationKernelClusterInfo.  # noqa: E501


        :return: The created_dt of this ResponseOrganizationKernelClusterInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._created_dt

    @created_dt.setter
    def created_dt(self, created_dt):
        """Sets the created_dt of this ResponseOrganizationKernelClusterInfo.


        :param created_dt: The created_dt of this ResponseOrganizationKernelClusterInfo.  # noqa: E501
        :type created_dt: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_dt is None:  # noqa: E501
            raise ValueError("Invalid value for `created_dt`, must not be `None`")  # noqa: E501

        self._created_dt = created_dt

    @property
    def id(self):
        """Gets the id of this ResponseOrganizationKernelClusterInfo.  # noqa: E501


        :return: The id of this ResponseOrganizationKernelClusterInfo.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ResponseOrganizationKernelClusterInfo.


        :param id: The id of this ResponseOrganizationKernelClusterInfo.  # noqa: E501
        :type id: int
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def kubernetes_namespace(self):
        """Gets the kubernetes_namespace of this ResponseOrganizationKernelClusterInfo.  # noqa: E501


        :return: The kubernetes_namespace of this ResponseOrganizationKernelClusterInfo.  # noqa: E501
        :rtype: str
        """
        return self._kubernetes_namespace

    @kubernetes_namespace.setter
    def kubernetes_namespace(self, kubernetes_namespace):
        """Sets the kubernetes_namespace of this ResponseOrganizationKernelClusterInfo.


        :param kubernetes_namespace: The kubernetes_namespace of this ResponseOrganizationKernelClusterInfo.  # noqa: E501
        :type kubernetes_namespace: str
        """
        if self.local_vars_configuration.client_side_validation and kubernetes_namespace is None:  # noqa: E501
            raise ValueError("Invalid value for `kubernetes_namespace`, must not be `None`")  # noqa: E501

        self._kubernetes_namespace = kubernetes_namespace

    @property
    def organization_name(self):
        """Gets the organization_name of this ResponseOrganizationKernelClusterInfo.  # noqa: E501


        :return: The organization_name of this ResponseOrganizationKernelClusterInfo.  # noqa: E501
        :rtype: str
        """
        return self._organization_name

    @organization_name.setter
    def organization_name(self, organization_name):
        """Sets the organization_name of this ResponseOrganizationKernelClusterInfo.


        :param organization_name: The organization_name of this ResponseOrganizationKernelClusterInfo.  # noqa: E501
        :type organization_name: str
        """
        if self.local_vars_configuration.client_side_validation and organization_name is None:  # noqa: E501
            raise ValueError("Invalid value for `organization_name`, must not be `None`")  # noqa: E501

        self._organization_name = organization_name

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResponseOrganizationKernelClusterInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ResponseOrganizationKernelClusterInfo):
            return True

        return self.to_dict() != other.to_dict()
